@@ -1,4 +1,4 @@
-# Udev::FFI - Copyright (C) 2017-2018 Ilya Pavlov
+# Udev::FFI - Copyright (C) 2017-2019 Ilya Pavlov
 # Udev::FFI is licensed under the
 # GNU Lesser General Public License v2.1
 
@@ -7,7 +7,7 @@ package Udev::FFI;
 use strict;
 use warnings;
 
-use Carp qw( croak );
+use Carp qw(croak);
 
 use Udev::FFI::Functions qw(:all);
 use Udev::FFI::Device;
@@ -15,7 +15,7 @@ use Udev::FFI::Monitor;
 use Udev::FFI::Enumerate;
 
 
-$Udev::FFI::VERSION = '0.102000';
+$Udev::FFI::VERSION = '0.102001';
 
 
 
@@ -32,7 +32,7 @@ sub new {
 
     my $self = {_context => udev_new()};
     if(!defined($self->{_context})) {
-        $@ = "Can't create udev context";
+        $@ = "Can't create udev context: $!";
         return undef;
     }
 
@@ -153,6 +153,7 @@ Udev::FFI - Perl bindings for libudev using ffi.
 =head1 SYNOPSIS
 
     use Udev::FFI;
+    use Udev::FFI::Devnum qw(:all); # <- import major, minor and makedev
     
     # get udev library version
     my $udev_version = Udev::FFI::udev_version() or
@@ -169,13 +170,13 @@ Udev::FFI - Perl bindings for libudev using ffi.
         die "Can't create udev monitor: $@";
     
     # add filter to monitor
-    unless($monitor->filter_by_subsystem_devtype('block')) {
+    unless ($monitor->filter_by_subsystem_devtype('block')) {
         warn "Ouch!";
     }
     
     # start monitor
-    if($monitor->start()) {
-        for(;;) {
+    if ($monitor->start()) {
+        for (;;) {
             # poll devices, now insert or remove your block device
             my $device = $monitor->poll(); #blocking read
             my $action = $device->get_action();
@@ -187,9 +188,9 @@ Udev::FFI - Perl bindings for libudev using ffi.
             last; # for example
         }
     
-        for(;;) {
+        for (;;) {
             # poll devices, now insert or remove your block device
-            if(defined(my $device = $monitor->poll(0))) { #non-blocking read like can_read in IO::Select
+            if (defined(my $device = $monitor->poll(0))) { #non-blocking read like can_read in IO::Select
                 my $action = $device->get_action();
     
                 print 'ACTION: '.$action, "\n";
@@ -221,14 +222,15 @@ Udev::FFI - Perl bindings for libudev using ffi.
     my @a = $enumerate->get_list_entries();
     print Dumper(@a), "\n";
     
-    if(@a) { # get major and minor
-        use Udev::FFI::Devnum qw(:all); # import major, minor and makedev
-    
+    if (@a) { # we got devices
         my $device = $udev->new_device_from_syspath($a[0]);
-        if(defined $device) {
+    
+        if (defined $device) {
             print "Device: ".$device->get_sysname(), "\n";
     
             my $devnum = $device->get_devnum();
+    
+            # major, minor and makedev from Udev::FFI::Devnum
             my ($ma, $mi) = (major($devnum), minor($devnum));
     
             print "Major: $ma\n";
@@ -256,7 +258,7 @@ Udev::FFI exposes OO interface to libudev.
  
 =over 4
  
-=item new ()
+=item new()
  
 This is the constructor for a new Udev::FFI object.
 
@@ -270,7 +272,7 @@ $@.
 
 =head1 METHODS
 
-=head2 new_monitor ( [SOURCE] )
+=head2 new_monitor( [SOURCE] )
 
 Create new udev monitor and connect to a specified event source. Valid sources
 identifiers are C<'udev'> and C<'kernel'>. This argument is optional and
@@ -282,7 +284,7 @@ on failure.
     my $monitor = $udev->new_monitor() or
         die "Can't create udev monitor: $@";
 
-=head2 new_enumerate ()
+=head2 new_enumerate()
 
 Create an enumeration context to scan /sys.
 
@@ -292,7 +294,7 @@ on failure.
     my $enumerate = $udev->new_enumerate() or
         die "Can't create enumerate context: $@";
 
-=head2 new_device_from_syspath ( SYSPATH )
+=head2 new_device_from_syspath( SYSPATH )
 
 Create new udev device, and fill in information from the sys device and the udev
 database entry. The syspath is the absolute path to the device, including the
@@ -305,11 +307,11 @@ Return new L<Udev::FFI::Device> object or undef, if device does not exist.
     
     # ... some code
     my @devices = $enumerate->get_list_entries();
-    for(@devices) {
+    for (@devices) {
         my $device = $udev->new_device_from_syspath($_);
     # ... some code
 
-=head2 new_device_from_devnum ( TYPE, DEVNUM )
+=head2 new_device_from_devnum( TYPE, DEVNUM )
 
 Create new udev device, and fill in information from the sys device and the udev
 database entry. The device is looked-up by its type and major/minor number.
@@ -320,7 +322,7 @@ Return new L<Udev::FFI::Device> object or undef, if device does not exist.
     my $device0 = $udev->new_device_from_devnum('b', makedev(8, 1));
     my $device1 = $udev->new_device_from_devnum('c', makedev(189, 515));
 
-=head2 new_device_from_subsystem_sysname ( SUBSYSTEM, SYSNAME )
+=head2 new_device_from_subsystem_sysname( SUBSYSTEM, SYSNAME )
 
 Create new udev device, and fill in information from the sys device and the udev
 database entry. The device is looked up by the subsystem and name string of the
@@ -332,7 +334,7 @@ Return new L<Udev::FFI::Device> object or undef, if device does not exist.
     my $device1 = $udev->new_device_from_subsystem_sysname('net', 'lo');
     my $device2 = $udev->new_device_from_subsystem_sysname('mem', 'urandom');
 
-=head2 new_device_from_device_id ( ID )
+=head2 new_device_from_device_id( ID )
 
 Create new udev device, and fill in information from the sys device and the udev
 database entry. The device is looked-up by a special string:
@@ -353,7 +355,7 @@ Return new L<Udev::FFI::Device> object or undef, if device does not exist.
 
     my $device = $udev->new_device_from_device_id('b8:1');
 
-=head2 new_device_from_environment ()
+=head2 new_device_from_environment()
 
 Create new udev device, and fill in information from the current process
 environment. This only works reliable if the process is called from a udev rule.
@@ -367,11 +369,11 @@ Return new L<Udev::FFI::Device> object or undef, if device does not exist.
     my $udev = Udev::FFI->new() or
         die "Can't create Udev::FFI object: $@";
     my $device = $udev->new_device_from_environment();
-    if(defined $device) {
+    if (defined $device) {
         # $device is the device from the udev rule (backlight in this example)
         # work with $device
 
-=head2 Udev::FFI::udev_version ()
+=head2 Udev::FFI::udev_version()
 
 Return the version of the udev library. Because the udev library does not
 provide a function to get the version number, this function runs the `udevadm`
@@ -387,11 +389,11 @@ ENOENT (`udevadm` not found) or EACCES (permission denied).
     # or catch the error
     use Errno qw( :POSIX );
     my $udev_version = Udev::FFI::udev_version();
-    unless(defined $udev_version) {
-        if($!{ENOENT}) {
+    unless (defined $udev_version) {
+        if ($!{ENOENT}) {
             # udevadm not found
         }
-        elsif($!{EACCES}) {
+        elsif ($!{EACCES}) {
             # permission denied
         }
     
